// PRUSA Mendel  
// X-end with NEMA 17 motor mount
// GNU GPL v2
// Josef Průša
// josefprusa@me.com
// prusadjs.cz
// http://www.reprap.org/wiki/Prusa_Mendel
// http://github.com/prusajr/PrusaMendel

include <configuration.scad>


module x_end_motor_nema23()
{
	translate(v = [0,17,24.5])
	union(){
	difference(){
	translate(v = [-50, -60, -24.5]) cube(size = [85,40,63]);
	
	// remove some excess material
	translate(v = [-30, -65, 6]) cube(size = [30,40,35]);
	
	// hole for y-axis rod
	translate([-100,-40,11]) rotate([0,90,0]) rotate([0, 0, 22.5]) cylinder(r=4,h=200,$fn=8);
	
	// wide y-axis hole to reduce friction in the center
	translate([-40,-40,11]) rotate([0,90,0]) rotate([0, 0, 22.5]) cylinder(r=5,h=50,$fn=8);

	//nut traps and set screws to hold x-rods
	for ( y = [-29, -50] )
		for ( x = [-25, 25] )
			{
			translate(v = [x, y, -17]) cylinder(h = 7, r=m3_nut_diameter/2, $fn=6, center=true);
			translate(v = [x, y, -25.5]) cylinder(h = 10, r=m3_diameter/2, $fn=9, center=true);
			}

	//belts
	for ( x = [-40, 10] )
		{
		// belt bolts
		for ( y = [-30, -50] )
			translate(v = [x, y, 10.5]) cylinder(h = 80, r=2.2, $fn=9, center=true);
			
		// access to belt bolt nuts
		translate([x, -40, 0]) cube(size = [10, 30, 57], center = true);		
		
		for ( y = [-30, -50] )
			translate([x, y, 0]) cube(size = [10, 8, 61], center = true);		
		}

	//holes for x-axis rods
	for ( x = [-25, 25] )
		{
		translate(v = [x, -18, -12])
		rotate(a=[90,0,0])
			{
				cylinder(h = 120, r=4.5, $fn=15, center=true);
				translate(v = [0, 2.8, 0]) rotate(a=[0,0,45]) cube(size = [5,5,120], center = true);
			}
		}
	}


	//nema23 connector
	translate(v = [0, 0, -12])
	difference()
	{
		union()
		{
			translate(v = [32.5, 9, 22.5]) cube(size = [5,68,70], center = true);
			
			// triangle support
			translate([0, 0, -11])
			linear_extrude(height = 3, center = true)
			polygon(points=[[32.5,-22.5],[30,43],[-33,-20]], paths=[[0,1,2]]);
		}

		translate(v = [32.5, 10, 23.5]) rotate(a=[0,90,0]) rotate(a=[0,0,30]) cylinder(h = 80, r=20, $fn=20, center=true);

		translate(v = [32.5, 10+23.5, 23.5+23.5]) cube(size = [20,5,10], center = true);
		translate(v = [32.5, 10-23.5, 23.5+23.5]) cube(size = [20,5,10], center = true);
		translate(v = [32.5, 10+23.5, 23.5-23.5]) cube(size = [20,5,10], center = true);
		translate(v = [32.5, 10-23.5, 23.5-23.5]) cube(size = [20,5,10], center = true);
	}
	}
}

//translate([0, 0, 25])
//rotate([180, 0, 0])
x_end_motor_nema23();
